#ifndef _PY_MOD_TIMER_H_
#define _PY_MOD_TIMER_H_

void python_gc_timer_module_init(void);

#endif
